==> huaweicloudsdkcloudrtc-3.1.96-py2.py3-none-any.whl: huaweicloudsdkcloudrtc/v1/model/list_rtc_event_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListRtcEventResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'ctime': 'str',
        'event_id': 'str',
        'event_info': 'str',
        'x_request_id': 'str'
    }

    attribute_map = {
        'ctime': 'ctime',
        'event_id': 'event_id',
        'event_info': 'event_info',
        'x_request_id': 'X-request-id'
    }

    def __init__(self, ctime=None, event_id=None, event_info=None, x_request_id=None):
        """ListRtcEventResponse

        The model defined in huaweicloud sdk

        :param ctime: 时间 
        :type ctime: str
        :param event_id: 异常事件ID 
        :type event_id: str
        :param event_info: 异常事件信息 
        :type event_info: str
        :param x_request_id: 
        :type x_request_id: str
        """
        
        super(ListRtcEventResponse, self).__init__()

        self._ctime = None
        self._event_id = None
        self._event_info = None
        self._x_request_id = None
        self.discriminator = None

        if ctime is not None:
            self.ctime = ctime
        if event_id is not None:
            self.event_id = event_id
        if event_info is not None:
            self.event_info = event_info
        if x_request_id is not None:
            self.x_request_id = x_request_id

    @property
    def ctime(self):
        """Gets the ctime of this ListRtcEventResponse.

        时间 

        :return: The ctime of this ListRtcEventResponse.
        :rtype: str
        """
        return self._ctime

    @ctime.setter
    def ctime(self, ctime):
        """Sets the ctime of this ListRtcEventResponse.

        时间 

        :param ctime: The ctime of this ListRtcEventResponse.
        :type ctime: str
        """
        self._ctime = ctime

    @property
    def event_id(self):
        """Gets the event_id of this ListRtcEventResponse.

        异常事件ID 

        :return: The event_id of this ListRtcEventResponse.
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this ListRtcEventResponse.

        异常事件ID 

        :param event_id: The event_id of this ListRtcEventResponse.
        :type event_id: str
        """
        self._event_id = event_id

    @property
    def event_info(self):
        """Gets the event_info of this ListRtcEventResponse.

        异常事件信息 

        :return: The event_info of this ListRtcEventResponse.
        :rtype: str
        """
        return self._event_info

    @event_info.setter
    def event_info(self, event_info):
        """Sets the event_info of this ListRtcEventResponse.

        异常事件信息 

        :param event_info: The event_info of this ListRtcEventResponse.
        :type event_info: str
        """
        self._event_info = event_info

    @property
    def x_request_id(self):
        """Gets the x_request_id of this ListRtcEventResponse.

        :return: The x_request_id of this ListRtcEventResponse.
        :rtype: str
        """
        return self._x_request_id

    @x_request_id.setter
    def x_request_id(self, x_request_id):
        """Sets the x_request_id of this ListRtcEventResponse.

        :param x_request_id: The x_request_id of this ListRtcEventResponse.
        :type x_request_id: str
        """
        self._x_request_id = x_request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListRtcEventResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcloudrtc-3.1.156-py2.py3-none-any.whl: huaweicloudsdkcloudrtc/v1/model/list_rtc_event_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListRtcEventResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'ctime': 'str',
        'event_id': 'str',
        'event_info': 'str',
        'x_request_id': 'str'
    }

    attribute_map = {
        'ctime': 'ctime',
        'event_id': 'event_id',
        'event_info': 'event_info',
        'x_request_id': 'X-request-id'
    }

    def __init__(self, ctime=None, event_id=None, event_info=None, x_request_id=None):
        r"""ListRtcEventResponse

        The model defined in huaweicloud sdk

        :param ctime: 时间 
        :type ctime: str
        :param event_id: 异常事件ID 
        :type event_id: str
        :param event_info: 异常事件信息 
        :type event_info: str
        :param x_request_id: 
        :type x_request_id: str
        """
        
        super(ListRtcEventResponse, self).__init__()

        self._ctime = None
        self._event_id = None
        self._event_info = None
        self._x_request_id = None
        self.discriminator = None

        if ctime is not None:
            self.ctime = ctime
        if event_id is not None:
            self.event_id = event_id
        if event_info is not None:
            self.event_info = event_info
        if x_request_id is not None:
            self.x_request_id = x_request_id

    @property
    def ctime(self):
        r"""Gets the ctime of this ListRtcEventResponse.

        时间 

        :return: The ctime of this ListRtcEventResponse.
        :rtype: str
        """
        return self._ctime

    @ctime.setter
    def ctime(self, ctime):
        r"""Sets the ctime of this ListRtcEventResponse.

        时间 

        :param ctime: The ctime of this ListRtcEventResponse.
        :type ctime: str
        """
        self._ctime = ctime

    @property
    def event_id(self):
        r"""Gets the event_id of this ListRtcEventResponse.

        异常事件ID 

        :return: The event_id of this ListRtcEventResponse.
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        r"""Sets the event_id of this ListRtcEventResponse.

        异常事件ID 

        :param event_id: The event_id of this ListRtcEventResponse.
        :type event_id: str
        """
        self._event_id = event_id

    @property
    def event_info(self):
        r"""Gets the event_info of this ListRtcEventResponse.

        异常事件信息 

        :return: The event_info of this ListRtcEventResponse.
        :rtype: str
        """
        return self._event_info

    @event_info.setter
    def event_info(self, event_info):
        r"""Sets the event_info of this ListRtcEventResponse.

        异常事件信息 

        :param event_info: The event_info of this ListRtcEventResponse.
        :type event_info: str
        """
        self._event_info = event_info

    @property
    def x_request_id(self):
        r"""Gets the x_request_id of this ListRtcEventResponse.

        :return: The x_request_id of this ListRtcEventResponse.
        :rtype: str
        """
        return self._x_request_id

    @x_request_id.setter
    def x_request_id(self, x_request_id):
        r"""Sets the x_request_id of this ListRtcEventResponse.

        :param x_request_id: The x_request_id of this ListRtcEventResponse.
        :type x_request_id: str
        """
        self._x_request_id = x_request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListRtcEventResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
